# Project to calculate TOPSIS
It takes parameters such as input file, weights, impacts and name of result file and the calculate 
TOPSIS score and rank and outputs in the result file.

Name -> Aman Sharma
Roll No -> 101803676
